# Installation
    pip install aclib.cv

# Usage

``` python
from aclib.cv import Image, Dotset, DotsetLib, FontLib
from aclib.cv import Target, TargetList

im = Image.fromfile('filepath')
im.show()
```
